package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppGoods;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-15
 */
public interface IAppGoodsService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param goodsId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppGoods selectAppGoodsByGoodsId(String goodsId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appGoods 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppGoods> selectAppGoodsList(AppGoods appGoods);

    /**
     * 新增【请填写功能名称】
     *
     * @param appGoods 【请填写功能名称】
     * @return 结果
     */
    public int insertAppGoods(AppGoods appGoods);

    /**
     * 修改【请填写功能名称】
     *
     * @param appGoods 【请填写功能名称】
     * @return 结果
     */
    public int updateAppGoods(AppGoods appGoods);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param goodsIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppGoodsByGoodsIds(String[] goodsIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param goodsId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppGoodsByGoodsId(String goodsId);

    /**
     * 批量修改物料启用禁用状态
     * @param goodsIds
     */
    void changeGoodsIsEnableStatus(String[] goodsIds);
}
