package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppGoods;
import com.ruoyi.app.service.IAppGoodsService;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/goods")
public class AppGoodsController extends BaseController {
    @Autowired
    private IAppGoodsService appGoodsService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:goods:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppGoods.class)
    public TableDataInfo list(AppGoods appGoods) {
        startPage();
        List<AppGoods> list = appGoodsService.selectAppGoodsList(appGoods);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:goods:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppGoods appGoods) {
        List<AppGoods> list = appGoodsService.selectAppGoodsList(appGoods);
        ExcelUtil<AppGoods> util = new ExcelUtil<AppGoods>(AppGoods.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:goods:query')")
    @GetMapping(value = "/{goodsId}")
    public AjaxResult getInfo(@PathVariable("goodsId") String goodsId) {
        return success(appGoodsService.selectAppGoodsByGoodsId(goodsId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:goods:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppGoods appGoods) {
        return toAjax(appGoodsService.insertAppGoods(appGoods));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:goods:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppGoods appGoods) {
        return toAjax(appGoodsService.updateAppGoods(appGoods));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:goods:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{goodsIds}")
    public AjaxResult remove(@PathVariable String[] goodsIds) {
        return toAjax(appGoodsService.deleteAppGoodsByGoodsIds(goodsIds));
    }

    /**
     * 禁用启用状态
     */
    @PreAuthorize("@ss.hasPermi('system:location:edit')")
    @Log(title = "禁用启用状态", businessType = BusinessType.UPDATE)
    @PostMapping("/changeGoodsIsEnableStatus/{goodsIds}")
    public AjaxResult changeGoodsIsEnableStatus(@PathVariable String[] goodsIds) {
        appGoodsService.changeGoodsIsEnableStatus(goodsIds);
        return success("修改状态成功");
    }
}
